### Reproducibility Package
### 01. Data processing

### Function to load and clean each sheet ----
read_and_clean_sheet <- function(file_path, sheet_name, characteristics_df = NULL) {
  df <- readxl::read_excel(file_path, sheet = sheet_name) %>%
    dplyr::mutate(
      Author = trimws(Author),  # Trim leading and trailing spaces
      across(
        c(beta, `beta final`, `SE beta`, `SE beta final`, `Sample size`, t),
        as.numeric
      ),
      tau = `beta final`,   # Effect size for meta-analysis (baggr)
      se = `SE beta final`, # Standard error for meta-analysis (baggr)
      group = Author        # Grouping variable for baggr
    )
  
  # Optional merge with characteristics data
  if (!is.null(characteristics_df)) {
    df <- dplyr::left_join(df, dplyr::select(characteristics_df, -Author), by = "ID") %>%
      dplyr::mutate(
        IncomeF = ifelse(Income_group == "High income", "High income", "Non-High income")
      )
  }
  
  return(df)
}

### Load characteristics data ----
df_characteristics <- readxl::read_excel(file.path(path, "Data/Raw/Input_Data.xlsx"), "Characteristics")

df_characteristics <- df_characteristics %>%
  mutate(Region = recode(Region,
                         "East Asia & Pacific"       = "EAP",
                         "Europe & Central Asia"     = "ECA",
                         "Latin America & Caribbean" = "LAC",
                         "Middle East & North Africa"= "MENA",
                         "North America"             = "NAC",
                         "Sub-Saharan Africa"        = "SSA",
                         "South Asia"                = "SAS"
  ))

### Load and clean main outcome sheets ----
df_employment <- read_and_clean_sheet(file.path(path, "Data/Raw/Input_Data.xlsx"), "Employment", characteristics_df = df_characteristics)
df_sales      <- read_and_clean_sheet(file.path(path, "Data/Raw/Input_Data.xlsx"), "Sales", characteristics_df = df_characteristics)
df_profit     <- read_and_clean_sheet(file.path(path, "Data/Raw/Input_Data.xlsx"), "Profit", characteristics_df = df_characteristics)


# Employment
head(df_employment)
n_distinct(df_employment)
nrow(df_employment)

# Sales
head(df_sales)
n_distinct(df_sales)
nrow(df_sales)


# Profit
head(df_profit)
n_distinct(df_profit)
nrow(df_profit)



# Save the employment data
write_xlsx(df_employment, file.path(path, "Data/Intermediate/df_employment.xlsx"))

# Save the Sales data
write_xlsx(df_sales, file.path(path, "Data/Intermediate/df_sales.xlsx"))

# Save the Profit data
write_xlsx(df_profit, file.path(path, "Data/Intermediate/df_profit.xlsx"))
